@@ -5,7 +5,7 @@
 
 """
 import datetime
-
+import threading
 import requests
 
 模块开始 = datetime.datetime.now()
@@ -19,18 +19,8 @@ from Fishconsole import files
 
 
 
-# 判断设备是否接入网络
-def isConnected():
-    import requests
-    # noinspection PyBroadException
-    try:
 
-        requests.get("https://pypi.org/project/Fishconsole/", timeout=7)
-    except:
-        print(logs.日志("》强制更新系统》官网连接失败"))
-        return False
-    print(logs.日志("》强制更新系统》官网连接成功"))
-    return True
+
 
 
 # 导入强制更新系统所需要的内容
@@ -82,6 +72,28 @@ def 系统日志(text, 项目名,开启状态=False):
 
 
 
+def 官网存活性检测(官网地址: str,测试时长=15):
+    """
+    Fishconsole Fishsys官网存活性检测
+
+    ----
+
+    - 就是判断官网能不能链接，可以用来检测联网，能联返回ture，不能返回False
+
+    :param 官网地址: 官网地址
+    :return: 布尔值
+    """
+    import requests
+    # noinspection PyBroadException
+    try:
+        print(logs.日志("尝试对官网进行连接"))
+        headers = {
+            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/101.0.4951.64 Safari/537.36 Edg/101.0.1210.53"
+        }
+        requests.get(官网地址, headers=headers, timeout=测试时长)
+    except:
+        return False
+    return True
 
 
 
@@ -94,27 +106,284 @@ def 系统日志(text, 项目名,开启状态=False):
 
 
 
+报警器=False
+def Fishconsole_Update():
+    # 你要删我也没办法，反正如果出了什么错过了重大更新你就自己乐呵去呗
+    # 这个不是模块，我们将会在导入该模块的时候顺序执行此处
+    # 你可以去fcv_debug关闭强制更新而不是删代码,删了对你没有多大好处
+
+    # 强制更新系统执行组一期
+
+    # 判断设备是否接入网络
+    global 报警器
+
+
+    def isConnected():
+        import requests
+        # noinspection PyBroadException
+        try:
+            requests.get("https://pypi.org/project/Fishconsole/", timeout=7)
+        except:
+            global 报警器
+            报警器=True
+            print(logs.日志("》强制更新系统》isConnected》官网连接失败"))
+            logs.变量查看("报警器",报警器)
+
+            return False
+        print(logs.日志("》强制更新系统》官网连接成功"))
+        return True
+
+
+    UPI=files.缓存(2,变量名="UPI")
+    if UPI=="error":
+        UPI=False
+        temp=files.缓存(2)
+        temp["UPI"]=False
+        files.缓存(1,temp)
+
+    UPI=files.缓存(2,变量名="UPI")
+    if UPI=="error":
+        UPI=False
+        temp=files.缓存(2)
+        temp["UPI"]=False
+        files.缓存(1,temp)
+
+    updata = files.缓存(2, 变量名="updata")
+    if updata == "error":
+        updata = True
+        temp=files.缓存(2)
+        temp["updata"]=True
+        files.缓存(1,temp)
+
+    Forcedupdate = files.缓存(2, 变量名="Forcedupdate")
+    if Forcedupdate == "error":
+        Forcedupdate = True
+        temp=files.缓存(2)
+        temp["Forcedupdate"]=True
+        files.缓存(1,temp)
+
+    系统日志("获取变量","强制更新系统", UPI)
+
+
+    # 查找缓存文件
+    config = files.缓存(2)
+    # 如果缓存文件不存在
+    if not config:
+        系统日志("强制更新系统》缓存》缓存文件不存在，创建缓存文件","强制更新系统", UPI)
+        # fup的意思是Fishsys模块判断自己是否在之前检测过一次，如果检测过一次，就是修改为正，让它可
+        # +以在下一次检测到版本还是低的话继续保持未检测的状态，如果成功了，那就将False修改为ture，这个fupadta是独立的
+        # +而updata是helps.帮助弄过来的，它的用处就是让Fishsys执行强制更新的操作
+        # 因为没有文件，所以我们在一开始就要创建文件，这个创建文件有一个规则，就是需要创建啥就写入啥，不要一股脑全写，因为这样就显得不高效
+        config = {"updata": True, "fup":True, "year": 2002, "month": 6, "day": 3}
+        系统日志("强制更新系统》首次运行，添加fup到缓存","强制更新系统", UPI)
+        # 提取数据，其实也是初始化首次启动时要用的变量，因为是第一次启动，所以提取的值就是首次运行的初始值
+        fup = config["fup"]
+        updata = config["updata"]
+        year = config['year']
+        # 当变量有点修改的时候我们就要进行保存，因为这样才能避免出现突如其来的故障
+        files.缓存(1, config)
+    else:
+        # 当缓存文件存在时执行的操作
+        系统日志(f"缓存文件存在，尝试读取相关信息","强制更新系统", UPI)
+        # 因为我们有文件了，我们就可以直接提取数据，但是难免会出现一些奇奇怪怪的情况，所以我们还要检测参数是否存在
+
+        fup = config.get("fup")
+
+
+        year = config.get("year")
+        day = config.get("day")
+        month = config.get("month")
+        系统日志(f"Forcedupdate is {fup}","强制更新系统", UPI)
+        系统日志(f"fup is {fup}","强制更新系统", UPI)
+        系统日志(f"updata is {updata}","强制更新系统", UPI)
+        系统日志(f"year is {year}","强制更新系统", UPI)
+
+
+    # 确认开发者模式是否启动了强制更新，但在之前必须导入变量
+    if Forcedupdate:
+        if updata:
+            系统日志("强制更新系统》强制更新系统启动","强制更新系统", UPI)
+            系统日志("强制更新系统》读取缓存信息","强制更新系统", UPI)
+            # 如果get到没有的内容，他就会给你返回False的布尔值
+            if year and month and day  is None:
+                系统日志("year配置不存在，创建","强制更新系统", UPI)
+                config["year"] = 2005
+                config["month"] = 6
+                config["day"] = 11
+                上一年 = config.get("year")
+                上一月 = config.get("month")
+                上一日 = config.get("day")
+                files.缓存(1, config)
+            else:
+                上一年 = config.get("year")
+                上一月 = config.get("month")
+                上一日 = config.get("day")
+
+            if updata is None:
+                系统日志("updata配置不存在，创建","强制更新系统", UPI)
+                config["updata"] = True
+                files.缓存(1, config)
+
+            if fup is None:
+                系统日志("fup配置不存在，创建","强制更新系统", UPI)
+                config["fup"] = True
+                fup = config["fup"]
+                files.缓存(1, config)
+            # 计算经过时间，如果经过的时间大于5，我们就要启动自动更新，通过这种被动更新的方式，我们就能确保用户使用的永远是最新版本
+
+        # 强制更新系统执行组二期
+        import time
+        a = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
+        a = a.split(" ")[0]
+        a = a.split("-")
+        年 = int(a[0])
+        月 = int(a[1])
+        日 = int(a[2])
+        上一年 = config.get("year")
+        上一月 = config.get("month")
+        上一日 = config.get("day")
+        if 上一年:
+            # 这是有数据时执行的
+            # noinspection PyStatementEffect
+            1 + 1
+        else:
+            config["year"] = "2005"
+            config["month"] = "6"
+            config["day"] = "3"
+            上一年 = 2005
+            上一月 = 6
+            上一日 = 3
+        # 结束时间就是今天的时间
+        # 开始时间就是自上次记录的时间，首次运行所记录的上次的时间默认为我的生日，不管生活有多么狼狈，生日那天也是要好好奖励自己的
+        try:
+            结束时间 = datetime.datetime(年, 月, 日)
+            开始时间 = datetime.datetime(上一年, 上一月, 上一日)
+        except ValueError:
+            报警器=True
+            logs.安全退出("强制更新系统》缓存文件遭到非法修改")
+        经过时间 = (结束时间 - 开始时间).days
+        if 经过时间 >= 5:
+            config["updata"] = True
+            config["year"] = 年
+            config["month"] = 月
+            config["day"] = 日
+            files.缓存(1, config)
+            报警器=True
+            print(logs.日志("强制更新系统》自动更新》Fishconsole Project自动更新已对您设备上的Fishconsole进行了例行的更新检查","红色"))
+
+
+            # updata在前面的参数提取中搞就已经好了，现在我们只需要执行操作了
+        if updata:
+            系统日志("这是updata值为True时执行的操作","强制更新系统", UPI)
+             # 查找fup的变量值，关于fup的介绍在822行，他肯定是存在的，如果不存在的就跑不到这一步了
+             # 这是fup开启时执行的操作
+            if fup:
+                # 这是fup开启时执行的操作
+                res = isConnected()
+                # 反转变量值，这样就可以在下一次执行的时候触发更新
+                config["fup"] = False
+                files.缓存(1, config)
+                if res:
+                    # 返回值不是False，就说明官网存活，也说明我们链接上了官网
+                    print(logs.日志(f"》Fishconsole强制更新系统{fcv.version()}》Fishsys 》您的版本过低，我们将尝试自动为您更新", "红色"))
+                    # 最原始的操作，大家引以为戒
+                    # os.remove("Fishconsole.fcc")
+                    系统日志(f"fup is {fup}","强制更新系统", UPI)
+                    try:
+                        os.system("python.exe -m pip install --upgrade pip -i https://pypi.douban.com/simple")
+                        os.system(f'pip install Fishconsole --upgrade')
+                    except:
+                        报警器 = True
+                        logs.日志("强制更新系统》pip命令组出现未知错误，程序强制退出","红色")
+                    报警器 = True
+                    logs.日志("强制更新系统》更新完毕，请重新运行", "红色")
+                else:
+                    报警器 = True
+                    logs.日志("强制更新系统》官网链接失败", "红色")
+
+            else:
+                # 这是Fishsys的复检或者是没有fup变量时执行的操作
+                # 反转变量值，这样就可以在下一次时触发警告
+                config["fup"] = True
+                # 只要缓存出现一次变化，我们就要把他存到fcc当中，只有这样我们才能保证它在异常关闭的时候数据不会丢失
+                files.缓存(1, config)
+
+                UPI = files.缓存(2, 变量名="UPI")
+                if UPI == "error":
+                    UPI = False
+
+                Forcedupdate = files.缓存(2, 变量名="Forcedupdate")
+                if Forcedupdate == "error":
+                    Forcedupdate = True
+
+                sys = files.缓存(2, 变量名="updata")
+                if sys == "error":
+                    sys = True
 
 
 
+                系统日志(f"读取缓存信息Foreceupdata [{Forcedupdate}]", "强制更新系统help", UPI)
+                系统日志(f"读取缓存信息sys[{sys}]", "强制更新系统help", UPI)
 
+                系统日志(f"这是强制更新系统开启时的操作", "强制更新系统help", UPI)
+                isConnected = 官网存活性检测("https://pypi.org/project/Fishconsole/")
+                if Forcedupdate:
+                    if isConnected:
+                        系统日志(f"检测到网络连接成功", "强制更新系统help", UPI)
+                        print(logs.日志(f"Fishconsole{fcv.version()} 检查更新开始。。。"))
+                        v = fcv.version()
+                        url = "https://pypi.org/project/Fishconsole/"
+                        res = requests.get(url).text
+                        res_html = etree.HTML(res)
+                        res_v = res_html.xpath("/html/body/main/div[2]/div/div[1]/h1/text()")[0]
+                        res_v = str(res_v[21:27])
+                        系统日志(f"res_v is {res_v}", "强制更新系统help", UPI)
+                        系统日志(f"v is {v}", "强制更新系统help", UPI)
+                        # 开启了强制更新系统
+                        if res_v == v:
+                            print(logs.日志(f"Fishconsole{fcv.version()} 检查更新结束,您的模块为最新版本", "绿色"))
+                            print(logs.日志(f"Fishconsole{fcv.version()} 已解锁，您可以使用了", "绿色"))
+                            # 尝试获取缓存中的值
+                            config = files.缓存(2)
+                            if config:
+                                系统日志("这是缓存获取成功时执行的操作", "强制更新系统helps", UPI)
+                                config["updata"] = False
+                                files.缓存(1, config)
+                                config["year"] = 2002
+                                config["month"] = 6
+                                config["day"] = 3
+                            else:
+                                系统日志("这是缓存获取失败时执行的操作", "强制更新系统helps", UPI)
+                                config = {"year": 2002, "month": 6, "day": 3, "updata": False}
+                                files.缓存(1, config)
+                        else:
+                            # 对比到版本号不同
+                            系统日志(f"对比到版本号不同", "强制更新系统help", UPI)
+                            print(logs.日志(f"Fishconsole{fcv.version()} 检查更新结束"))
+                            # 尝试获取缓存中的值
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+                            # 这是没有检查到值或者发现时执行的操作
+                            print(logs.日志(f"检测到最新版本号发生了变化({res_v}>{v})，请重新运行本程序，我们将尝试自动安装最新版本", "红色"))
+                            print(logs.日志(f"Fishconsole 模块已被禁用，解决方式为更新该模块", "红色"))
+                            config = files.缓存(2)
+                            系统日志(f"config is {config}", "强制更新系统help", UPI)
+                            config["updata"] = True
+                            files.缓存(1, config)
+                            报警器 = True
+                            print(logs.日志(f"Fishconsole 》强制更新启动", "红色"))
+                    else:
+                        print(logs.日志(f"Fishconsole{fcv.version()} 检查更新结束"))
+                        报警器 = True
+                        print(logs.日志(f"Fishconsole 》你的设备无法访问互联网，请检查网络连接", "红色"))
+                else:
+                    print(logs.日志(f"Fishconsole{fcv.version()} 开发者您好,我们已经停止了强制更新。请注意，全局配置已重置", "绿色"))
+                    print(logs.日志(f"Fishconsole{fcv.version()} 已解锁，您可以使用了", "绿色"))
+                    # 尝试获取缓存中的值
+                    config = files.缓存(2)
+                    fupdata = config.get("updata")
+                    if fupdata:
+                        config["updata"] = False
+                        files.缓存(1, config)
 
 
 
@@ -155,11 +424,13 @@ def passwordsys(模式: any, id_protect: str, password_a: str):
             res_a = res_a + a
             if a == "@":
                 print(logs.颜色(logs.日志(""), 色选="红色"))
+                报警器 = True
                 logs.安全退出("你的密码中不允许有@符号，请重新输入")
 
         for b in id_protect:
             res_b = res_b + b
             if b == "@":
+                报警器 = True
                 logs.安全退出(logs.日志("你的原文中不允许有@符号，请重新输入", 色选="红色"))
 
         else:
@@ -683,28 +954,7 @@ def 字符转unicode(模式, 原文: str):
         logs.错误跟踪(["Fishconsole", "字符串转unicode", "模式"], "请选择正确的模式", {模式})
 
 
-def 官网存活性检测(官网地址: str,测试时长=15):
-    """
-    Fishconsole Fishsys官网存活性检测
 
-    ----
-
-    - 就是判断官网能不能链接，可以用来检测联网，能联返回ture，不能返回False
-
-    :param 官网地址: 官网地址
-    :return: 布尔值
-    """
-    import requests
-    # noinspection PyBroadException
-    try:
-        print(logs.日志("尝试对官网进行连接"))
-        headers = {
-            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/101.0.4951.64 Safari/537.36 Edg/101.0.1210.53"
-        }
-        requests.get(官网地址, headers=headers, timeout=测试时长)
-    except:
-        return False
-    return True
 
 
 def 讯飞云控(fid):
@@ -745,281 +995,8 @@ def 讯飞云控(fid):
         logs.安全退出("Fishsys》讯飞云控》网络链接失败")
     return res
 
-
-# 你要删我也没办法，反正如果出了什么错过了重大更新你就自己乐呵去呗
-# 这个不是模块，我们将会在导入该模块的时候顺序执行此处
-# 你可以去fcv_debug关闭强制更新而不是删代码,删了对你没有多大好处
-
-# 强制更新系统执行组一期
-
-UPI=files.缓存(2,变量名="UPI")
-if UPI=="error":
-    UPI=False
-    temp=files.缓存(2)
-    temp["UPI"]=False
-    files.缓存(1,temp)
-
-
-UPI=files.缓存(2,变量名="UPI")
-if UPI=="error":
-    UPI=False
-    temp=files.缓存(2)
-    temp["UPI"]=False
-    files.缓存(1,temp)
-
-updata = files.缓存(2, 变量名="updata")
-if updata == "error":
-    updata = True
-    temp=files.缓存(2)
-    temp["updata"]=True
-    files.缓存(1,temp)
-
-Forcedupdate = files.缓存(2, 变量名="Forcedupdate")
-if Forcedupdate == "error":
-    Forcedupdate = True
-    temp=files.缓存(2)
-    temp["Forcedupdate"]=True
-    files.缓存(1,temp)
-
-系统日志("获取变量","强制更新系统", UPI)
-
-
-# 查找缓存文件
-config = files.缓存(2)
-# 如果缓存文件不存在
-if not config:
-    系统日志("强制更新系统》缓存》缓存文件不存在，创建缓存文件","强制更新系统", UPI)
-    # fup的意思是Fishsys模块判断自己是否在之前检测过一次，如果检测过一次，就是修改为正，让它可
-    # +以在下一次检测到版本还是低的话继续保持未检测的状态，如果成功了，那就将False修改为ture，这个fupadta是独立的
-    # +而updata是helps.帮助弄过来的，它的用处就是让Fishsys执行强制更新的操作
-    # 因为没有文件，所以我们在一开始就要创建文件，这个创建文件有一个规则，就是需要创建啥就写入啥，不要一股脑全写，因为这样就显得不高效
-    config = {"updata": True, "fup":True, "year": 2002, "month": 6, "day": 3}
-    系统日志("强制更新系统》首次运行，添加fup到缓存","强制更新系统", UPI)
-    # 提取数据，其实也是初始化首次启动时要用的变量，因为是第一次启动，所以提取的值就是首次运行的初始值
-    fup = config["fup"]
-    updata = config["updata"]
-    year = config['year']
-    # 当变量有点修改的时候我们就要进行保存，因为这样才能避免出现突如其来的故障
-    files.缓存(1, config)
-else:
-    # 当缓存文件存在时执行的操作
-    系统日志(f"缓存文件存在，尝试读取相关信息","强制更新系统", UPI)
-    # 因为我们有文件了，我们就可以直接提取数据，但是难免会出现一些奇奇怪怪的情况，所以我们还要检测参数是否存在
-
-    fup = config.get("fup")
-
-
-    year = config.get("year")
-    day = config.get("day")
-    month = config.get("month")
-    系统日志(f"Forcedupdate is {fup}","强制更新系统", UPI)
-    系统日志(f"fup is {fup}","强制更新系统", UPI)
-    系统日志(f"updata is {updata}","强制更新系统", UPI)
-    系统日志(f"year is {year}","强制更新系统", UPI)
-
-
-# 确认开发者模式是否启动了强制更新，但在之前必须导入变量
-if Forcedupdate:
-    if updata:
-        系统日志("强制更新系统》强制更新系统启动","强制更新系统", UPI)
-        系统日志("强制更新系统》读取缓存信息","强制更新系统", UPI)
-        # 如果get到没有的内容，他就会给你返回False的布尔值
-        if year and month and day  is None:
-            系统日志("year配置不存在，创建","强制更新系统", UPI)
-            config["year"] = 2005
-            config["month"] = 6
-            config["day"] = 11
-            上一年 = config.get("year")
-            上一月 = config.get("month")
-            上一日 = config.get("day")
-            files.缓存(1, config)
-        else:
-            上一年 = config.get("year")
-            上一月 = config.get("month")
-            上一日 = config.get("day")
-
-        if updata is None:
-            系统日志("updata配置不存在，创建","强制更新系统", UPI)
-            config["updata"] = True
-            files.缓存(1, config)
-
-        if fup is None:
-            系统日志("fup配置不存在，创建","强制更新系统", UPI)
-            config["fup"] = True
-            fup = config["fup"]
-            files.缓存(1, config)
-        # 计算经过时间，如果经过的时间大于5，我们就要启动自动更新，通过这种被动更新的方式，我们就能确保用户使用的永远是最新版本
-
-    # 强制更新系统执行组二期
-    import time
-    a = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
-    a = a.split(" ")[0]
-    a = a.split("-")
-    年 = int(a[0])
-    月 = int(a[1])
-    日 = int(a[2])
-    上一年 = config.get("year")
-    上一月 = config.get("month")
-    上一日 = config.get("day")
-    if 上一年:
-        # 这是有数据时执行的
-        # noinspection PyStatementEffect
-        1 + 1
-    else:
-        config["year"] = "2005"
-        config["month"] = "6"
-        config["day"] = "3"
-        上一年 = 2005
-        上一月 = 6
-        上一日 = 3
-    # 结束时间就是今天的时间
-    # 开始时间就是自上次记录的时间，首次运行所记录的上次的时间默认为我的生日，不管生活有多么狼狈，生日那天也是要好好奖励自己的
-    try:
-        结束时间 = datetime.datetime(年, 月, 日)
-        开始时间 = datetime.datetime(上一年, 上一月, 上一日)
-    except ValueError:
-        logs.安全退出("强制更新系统》缓存文件遭到非法修改")
-    经过时间 = (结束时间 - 开始时间).days
-    if 经过时间 >= 5:
-        config["updata"] = True
-        config["year"] = 年
-        config["month"] = 月
-        config["day"] = 日
-        files.缓存(1, config)
-        print(logs.日志("强制更新系统》自动更新》Fishconsole Project自动更新已对您设备上的Fishconsole进行了例行的更新检查","红色"))
-
-
-        # updata在前面的参数提取中搞就已经好了，现在我们只需要执行操作了
-    if updata:
-        系统日志("这是updata值为True时执行的操作","强制更新系统", UPI)
-         # 查找fup的变量值，关于fup的介绍在822行，他肯定是存在的，如果不存在的就跑不到这一步了
-         # 这是fup开启时执行的操作
-        if fup:
-            # 这是fup开启时执行的操作
-            res = isConnected()
-            logs.变量查看("res",res)
-            # 反转变量值，这样就可以在下一次执行的时候触发更新
-            config["fup"] = False
-            files.缓存(1, config)
-            if res:
-                # 返回值不是False，就说明官网存活，也说明我们链接上了官网
-                print(logs.日志(f"》Fishconsole强制更新系统{fcv.version()}》Fishsys 》您的版本过低，我们将尝试自动为您更新", "红色"))
-                # 最原始的操作，大家引以为戒
-                # os.remove("Fishconsole.fcc")
-                系统日志(f"fup is {fup}","强制更新系统", UPI)
-                try:
-                    os.system("python.exe -m pip install --upgrade pip -i https://pypi.douban.com/simple")
-                    os.system(f'pip install Fishconsole --upgrade')
-                except:
-                    logs.安全退出("强制更新系统，pip命令组出现未知错误，程序强制退出")
-                logs.安全退出("更新完毕，请重新运行")
-            else:
-                logs.安全退出("强制更新系统》官网链接失败")
-        else:
-            # 这是Fishsys的复检或者是没有fup变量时执行的操作
-            print(logs.日志(f"》Fishconsole强制更新系统{fcv.version()}》Fishsys 》正在激活帮助及模块包更新检查工具", "红色"))
-            # 反转变量值，这样就可以在下一次时触发警告
-            config["fup"] = True
-            # 只要缓存出现一次变化，我们就要把他存到fcc当中，只有这样我们才能保证它在异常关闭的时候数据不会丢失
-            files.缓存(1, config)
-
-            UPI = files.缓存(2, 变量名="UPI")
-            if UPI == "error":
-                UPI = False
-            
-            Forcedupdate = files.缓存(2, 变量名="Forcedupdate")
-            if Forcedupdate == "error":
-                Forcedupdate = True
-            
-            sys = files.缓存(2, 变量名="updata")
-            if sys == "error":
-                sys = True
-            
-
-            
-            系统日志(f"读取缓存信息Foreceupdata [{Forcedupdate}]", "强制更新系统help", UPI)
-            系统日志(f"读取缓存信息sys[{sys}]", "强制更新系统help", UPI)
-
-            系统日志(f"这是强制更新系统开启时的操作", "强制更新系统help", UPI)
-            isConnected = 官网存活性检测("https://pypi.org/project/Fishconsole/")
-            if Forcedupdate:
-                if isConnected:
-                    系统日志(f"检测到网络连接成功", "强制更新系统help", UPI)
-                    print(logs.日志(f"Fishconsole{fcv.version()} 检查更新开始。。。"))
-                    v = fcv.version()
-                    url = "https://pypi.org/project/Fishconsole/"
-                    res = requests.get(url).text
-                    res_html = etree.HTML(res)
-                    res_v = res_html.xpath("/html/body/main/div[2]/div/div[1]/h1/text()")[0]
-                    res_v = str(res_v[21:27])
-                    系统日志(f"res_v is {res_v}", "强制更新系统help", UPI)
-                    系统日志(f"v is {v}", "强制更新系统help", UPI)
-                    # 开启了强制更新系统
-                    if res_v == v:
-                        print(logs.日志(f"Fishconsole{fcv.version()} 检查更新结束,您的模块为最新版本", "绿色"))
-                        print(logs.日志(f"Fishconsole{fcv.version()} 已解锁，您可以使用了", "绿色"))
-                        # 尝试获取缓存中的值
-                        config = files.缓存(2)
-                        if config:
-                            系统日志("这是缓存获取成功时执行的操作", "强制更新系统helps", UPI)
-                            config["updata"] = False
-                            files.缓存(1, config)
-                            config["year"] = 2002
-                            config["month"] = 6
-                            config["day"] = 3
-                        else:
-                            系统日志("这是缓存获取失败时执行的操作", "强制更新系统helps", UPI)
-                            config = {"year": 2002, "month": 6, "day": 3, "updata": False}
-                            files.缓存(1, config)
-                    else:
-                        # 对比到版本号不同
-                        系统日志(f"对比到版本号不同", "强制更新系统help", UPI)
-                        print(logs.日志(f"Fishconsole{fcv.version()} 检查更新结束"))
-                        # 尝试获取缓存中的值
-
-                        # 这是没有检查到值或者发现时执行的操作
-                        print(logs.日志(f"检测到最新版本号发生了变化({res_v}>{v})，请重新运行本程序，我们将尝试自动安装最新版本", "红色"))
-                        print(logs.日志(f"Fishconsole 模块已被禁用，解决方式为更新该模块", "红色"))
-                        config = files.缓存(2)
-                        系统日志(f"config is {config}", "强制更新系统help", UPI)
-                        config["updata"] = True
-                        files.缓存(1, config)
-                        logs.安全退出(f"Fishconsole》help》强制更新启动")
-
-
-                else:
-                    print(logs.日志(f"Fishconsole{fcv.version()} 检查更新结束"))
-                    print(logs.日志("你的设备无法访问互联网，请检查网络连接"))
-            else:
-                logs.日志(f"Fishconsole》f_debug》已取消强制更新", "绿色")
-                # 尝试获取缓存中的值
-                config = files.缓存(2)
-                fupdata = config.get("updata")
-                if fupdata:
-                    config["updata"] = False
-                    files.缓存(1, config)
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-else:
-    # 这是关闭了更新时执行的操作
-    print(logs.日志(f"Fishconsole{fcv.version()} 开发者您好,我们已经停止了强制更新。请注意，全局配置已重置", "绿色"))
-    print(logs.日志(f"Fishconsole{fcv.version()} 已解锁，您可以使用了", "绿色"))
-模块结束 = datetime.datetime.now()
+a=threading.Thread(target=Fishconsole_Update)
+a.start()
+a.join()
+if 报警器:
+    logs.安全退出("程序正常退出")
\ No newline at end of file
