@@ -16,7 +16,7 @@ def version():
 
     :return: 返回版本号
     """
-    return '1.1132'
+    return '1.1133'
 
 
 def f_debug():
@@ -52,11 +52,12 @@ def f_debug():
     # 欢迎您进入Fishconsole的调试控制模块，如果您想了解这个集合是如何运行的，请将mod的参数改为False
     # ，相信我，输出的内容可能会很多，它们能帮你了解这个模块核心组件的全部运行过程，我呢，只是一个职高生，做这
     # 个完全是为爱发电，所以，虽然我的模块不会很好，但正在努力前行——鱼几斤（2022/4/24）
-    from Fishconsole import logs, files, helps
+    from Fishconsole import logs, files, helps,Fishsys
     import os, pandas as pd
     from openpyxl.utils import get_column_letter
     from pandas import ExcelWriter
     import numpy as np
+    import threading
     def to_excel_auto_column_weight(df: pd.DataFrame, writer: ExcelWriter, sheet_name):
         """DataFrame保存为excel并自动设置列宽"""
         df.to_excel(writer, sheet_name=sheet_name, index=False)
@@ -125,13 +126,13 @@ def f_debug():
                     # 展示所有的变量，以Dateframe的形式
                     变量组value = files.缓存(2)
                     变量组info = {
-                        "updata": "强制更新系统激活状态",
+                        "updata": "Fishconsole强制更新系统激活状态",
                         "Forcedupdate": "Fishconsole强制更新运行状态",
-                        "fup": "Fishsys强制更新系统自检状态",
+                        "fup": "Fishconsole强制更新系统自检状态",
                         "year": "上一次更新的年",
                         "month": "上一次更新的月",
                         "day": "上一次更新的日",
-                        "UPI": "强制更新系统操作输出开关",
+                        "UPI": "Fishconsole强制更新系统操作输出开关",
                         "FI": "系统日志总开关",
                         "PI": "passworld系统日志输出控制",
                         "HEI": "helps主程序系统日志输出开关",
@@ -163,8 +164,10 @@ def f_debug():
 
                         with pd.ExcelWriter(r'Fishconsole.fcc.xlsx') as writer:
                             to_excel_auto_column_weight(res, writer, f'Fishconsole fcv_debug变量组')
-
-                        os.system("Fishconsole.fcc.xlsx")
+                        def start():
+                            os.system("Fishconsole.fcc.xlsx")
+                        a = threading.Thread(target=start)
+                        a.start()
                     except:
                         print("你个辣鸡，wps或者office都不装一个")
                         print(res)
@@ -337,6 +340,12 @@ def f_debug():
         elif b[0] in ["help", "?", "？","HELP"]:
             helps.帮助()
 
+        elif b[0] in ["updata","UPDATA"]:
+            print(logs.日志("Fcv_debug Console》我们将尝试激活更新，在程序执行完毕以后，我们将阻止强制更新系统在下一次继续运行","蓝色"))
+            files.缓存(3,数据={'updata':True})
+            Fishsys.Fishconsole_Update()
+            files.缓存(3, 数据={'updata': False})
+
         elif b[0] in ["execute"]:
             未选触发器 = True
             空容器=""
