@@ -6,9 +6,11 @@
 ----
 
 """
-
+import os
 import sys
 from Fishconsole import fcv
+# 显示行列要用
+import signal
 
 
 
@@ -185,13 +187,15 @@ def 安全退出(内容, 变量=None):
 
         :param 内容: 要显示的文字
         :param 变量: 传入的变量（默认没有）
-        :return: 显示你输入的文字并结束程序
+        :return: 显示你输入的文字并结束程
         """
     a = sys._getframe(1).f_lineno
     if 变量 is None:
         sys.exit(日志(f"》Fishconsole {fcv.version()}安全退出》{内容} || line[{a}] ", "红色"))
+
     else:
         变量查看("temp", 变量)
+        os.kill(os.getpid(),signal.SIGKILL)
         sys.exit(日志(f"》Fishconsole {fcv.version()}安全退出》{内容} || line[{a}] ", "红色"))
 
 
