@@ -12,11 +12,8 @@ import datetime
 
 import easygui
 # 虽然没什么用，但是里面的强制更新系统可以很好的牵制调用
-from Fishconsole import Fishsys
-from Fishconsole import logs
-from Fishconsole import fcv
+from Fishconsole import files,logs,fcv
 
-logs.系统日志("用户调用了window模块")
 
 
 def 弹窗(显示文字, 标题, 确认显示文字):
@@ -28,7 +25,7 @@ def 弹窗(显示文字, 标题, 确认显示文字):
 
 # noinspection PyStatementEffect
 def 选择对话框(显示文字, 标题, 选项: list, 图片地址: str = None):
-    a = Fishsys.强制类型检测(选项, "list")
+    a = files.强制类型检测(选项, "list")
     if a:
         1 + 1
     else:
@@ -41,7 +38,7 @@ def 选择对话框(显示文字, 标题, 选项: list, 图片地址: str = None
 
 # noinspection PyStatementEffect
 def 列表选择对话框(显示文字, 标题, 选项: list):
-    a = Fishsys.强制类型检测(选项, "list")
+    a = files.强制类型检测(选项, "list")
     if a:
         1 + 1
     else:
@@ -90,6 +87,3 @@ def 文件保存():
 # print(密码框("显示文字",["内容1","内容2"],"标题"))
 # print(文件选择())
 # print(文件保存())
-
-模块结束 = datetime.datetime.now()
-logs.系统日志(f'Fishsys运行时间为：{模块结束 - 模块开始}')
